<?php
namespace OCA\Dematpayslip\Db;

use OCP\IDbConnection;
use OCP\AppFramework\Db\QBMapper;

class DematpayslipArchiveMapper extends QBMapper {

    public function __construct(IDbConnection $db) {
        parent::__construct($db, 'dematpayslip_archive', DematpayslipArchive::class);
    }

    public function find(int $id) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('id', $qb->createNamedParameter($id))
            );

        return $this->findEntity($qb);
    }

    public function findAllByIdFile(int $idFile) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('id_file', $qb->createNamedParameter($idFile))
            );

        return $this->findEntities($qb);
    }

    public function findAllByFilePath(string $filePath) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('file_path', $qb->createNamedParameter($filePath))
            );

        return $this->findEntities($qb);
    }

    public function findAllByAgentAndPeriod(string $siret, string $matricule, string $lastname, string $firstname, string $start_date, string $end_date) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName())
            ->where(
                $qb->expr()->eq('siret', $qb->createNamedParameter($siret))
            )
            ->andWhere(
                $qb->expr()->eq('matricule', $qb->createNamedParameter($matricule))
            )
            ->andWhere(
                $qb->expr()->eq('lastname', $qb->createNamedParameter($lastname))
            )
            ->andWhere(
                $qb->expr()->eq('firstname', $qb->createNamedParameter($firstname))
            )
            ->andWhere(
                $qb->expr()->eq('start_date', $qb->createNamedParameter($start_date))
            )
            ->andWhere(
                $qb->expr()->eq('end_date', $qb->createNamedParameter($end_date))
            )
            ->andWhere(
                $qb->expr()->gte('status', $qb->createNamedParameter(DematpayslipArchive::STATUS_INITIALIZED))
            );;

        return $this->findEntities($qb);
    }

    public function findAllArchived(int $archived) {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*');
        $qb->from($this->getTableName());
        $qb->where(
            $qb->expr()->gte('status', $qb->createNamedParameter(DematpayslipArchive::STATUS_INITIALIZED))
        );

        if ($archived == 1) {
            $qb->andWhere(
                $qb->expr()->isNotNull('pastell_id_document')
            );
        } elseif ($archived == 0) {
            $qb->andWhere(
                $qb->expr()->isNull('pastell_id_document')
            );
        }

        return $this->findEntities($qb);
    }

    public function findAll() {
        $qb = $this->db->getQueryBuilder();

        $qb->select('*')
            ->from($this->getTableName());

        return $this->findEntities($qb);
    }
}
